<?php
/**
 * Modules markup
 *
 * @since   5.0
 *
 * @package LECO\Client_Portal\Blocks\Modules
 *
 * @var array    $attributes Block attributes.
 * @var string   $content    Block content.
 * @var WP_Block $block      Block instance.
 * @var array    $context    BLock context.
 */

// block variables
$complete    = isset( $attributes['complete'] ) ? $attributes['complete'] : 'active';
$title       = isset( $attributes['title'] ) ? $attributes['title'] : '';
$description = isset( $attributes['description'] ) ? $attributes['description'] : '';
$icon        = isset( $attributes['icon'] ) ? $attributes['icon'] : '';
$type		 = isset( $attributes['moduleType'] ) ? $attributes['moduleType'] : 'url';
$status 	 = isset( $attributes['status'] ) ? $attributes['status'] : 'inactive';
$openTab 	 = isset( $attributes['openTab'] ) ? $attributes['openTab'] : 'default';
$number      = isset( $block->context['leco-cp/phasesID'] ) ? $block->context['leco-cp/phasesID'] : 0;
$key		 = isset( $attributes['uid'] ) ? $attributes['uid'] : 0;
$phaseID     = isset( $attributes['phaseID'] ) ? $attributes['phaseID'] : false;
$color       = isset( $attributes['textColor'] ) ? sprintf( "var(--wp--preset--color--%s)", $attributes['textColor'] ) : '#3c5063';

// Module Type variables
$url          = isset( $attributes['moduleUrl'] ) ? $attributes['moduleUrl'] : '';
$content_page = isset( $attributes['moduleContentPage'] ) ? $attributes['moduleContentPage'] : false;
$links		  = isset( $attributes['moduleLinks'] ) ? $attributes['moduleLinks'] : array();
$files		  = isset( $attributes['moduleFiles'] ) ? $attributes['moduleFiles'] : array();
$privateFiles = isset( $attributes['modulePrivateFiles'] ) ? $attributes['modulePrivateFiles'] : array();
$uploads	  = isset( $attributes['moduleClientUploads'] ) ? $attributes['moduleClientUploads'] : array();

// plugin settings variables
$tab_setting = leco_cp_get_option( 'new_tab', 'new_tab' );

// classes
$unique_id_class    = "m_{$number}_{$key}";
$mark_complete_link = "#module_mark_as_complete_{$number}_{$key}";

// blank variables
$hover_status = '';
$link_target = '';

// uploaded files
$uploaded_files = array();

if (
	'yes' === $openTab ||
	( 'default' === $openTab && 'current' !== $tab_setting  )
) {
	$link_target = ' target="_blank"';
}

if ( 'inactive' === $status ) {
	$url          = 'javascript: void(0);';
	$hover_status = ' inactive';
} elseif ( 'module-url' === $type ) {
    if ( empty( $url ) ) {
        $url = 'javascript: void(0);';
        $hover_status = ' unclickable';
    }
} elseif ( 'module-content-page' === $type && $content_page ) {
	$content_page = get_post_field( 'post_name', $content_page );
	$url = trailingslashit( get_permalink( get_the_ID() ) . 'module/' . $content_page );
} elseif ( 'module-client-uploads' === $type ) { 
	$url = "#module_{$number}_$key";
	$link_target = '';
}
elseif ( 'module-files' === $type || 'module-private-files' === $type ) {

    $uploaded_files = 'module-files' === $type ? $files : $privateFiles;

    if ( empty( $uploaded_files ) ) {
        $url = 'javascript: void(0);';
        $hover_status = ' unclickable';
    }

    if ( count( $uploaded_files ) === 1 ) {
        $url = isset( $uploaded_files[0]['url'] ) ? $uploaded_files[0]['url'] : 'javascript: void(0);';
    } else {
        $url = "#module_{$number}_$key";
    }

    $link_target = '';

} elseif ( 'module-links' === $type ) {

    if ( empty( $links ) ) {
        $url = 'javascript: void(0);';
        $hover_status = ' unclickable';
    }

    if ( count( $links ) === 1 ) {
        $url = $links[0]['linkUrl'];
    } else {
        $url = "#module_{$number}_$key";
    }

} elseif ( empty( $url ) || '#' === $url ) {
	$url = 'javascript: void(0);';
    $link_target = '';

	if ( 'inactive' != $status ) {
		$hover_status = ' unclickable';
	}
}

?>

<div class="module-wrap <?php echo esc_attr( $unique_id_class ); ?>" id="<?php echo esc_attr( $phaseID ); ?>">
    <div class="checkbox-container">
        <?php if ( 'completed' === $status ) { ?>
            <span class="action checkmark">
                <span class="tooltip">
                    <?php _e( 'Completed', 'leco-cp' ) ?><span class="arrow"></span>
                </span>
            </span>
        <?php } ?>
        <?php
        if ( leco_cp_can_mark_as_complete( $attributes, get_the_ID() ) ) { ?>
            <a
                href="<?php echo esc_url( $mark_complete_link ); ?>"
                class="action checkmark mark-complete" data-leco-cp-mark-as-complete="true"
            >
                <span class="tooltip">
                    <?php echo apply_filters( 'leco_cp_mark_as_complete_text', esc_html__( 'Mark As Complete?', 'leco-cp' ) ); ?>
                    <span class="arrow"></span>
                </span>
            </a>
        <?php } ?>
    </div>
	<a
		id="<?php echo $unique_id_class ?>"
		class="module <?php echo esc_attr( $unique_id_class ); echo esc_attr( $hover_status ) ?>"
		href="<?php echo $url; ?>"
		<?php echo $link_target; ?>

		<?php if (
            ( 'module-links' === $type && count( $links ) > 1 ) || 
            ( 'module-files' === $type || 'module-private-files' === $type ) && count( $uploaded_files ) > 1 || 
            'module-client-uploads' === $type ) { 
			echo ' data-leco-cp-lity'; } 
		?>

        <?php if ( 'module-links' === $type && count( $links ) === 1 ) { ?>
            title="<?php echo esc_html( $links[0]['linkTitle'] ); ?>"
        <?php } ?>

        <?php if ( ( 'module-files' === $type || 'module-private-files' === $type )  && count( $uploaded_files ) === 1 ) { ?>
            title="<?php echo esc_html( $uploaded_files[0]['title'] ); ?>"
            download
        <?php } ?>
	>
		<span class="ico-area">
			<span class="iconset">
				<?php echo leco_cp_get_module_icon( $icon, $key, $number ); ?>
			</span>
		</span>
		<?php printf( '<span class="title" style="color: %2$s">%1$s</span>', wp_kses_post( $title ), esc_attr( $color ) ); ?>
		<?php printf( '<span class="description">%s</span>', wp_kses_post( $description ) ); ?>

		<?php if ( leco_cp_can_upload( $attributes, get_the_ID() ) ) { ?>
			<p class="upload">
				<?php echo file_get_contents( LECO_CLIENT_PORTAL_DIR . 'templates/five/assets/paperclip.svg' ); ?>

				<span><?php esc_html_e( 'add files', 'leco-cp' ); ?></span>
			</p>
		<?php } ?>
	</a>
</div>

<?php
if ( 'module-links' === $type ) {
	require LECO_CLIENT_PORTAL_DIR . '/templates/five/template-parts/multiple-urls.php';
}

if ( 'module-files' === $type || 'module-private-files' === $type ) {
	require LECO_CLIENT_PORTAL_DIR . '/templates/five/template-parts/filelist.php';
}

if ( 'module-client-uploads' === $type ) {
	require LECO_CLIENT_PORTAL_DIR . '/templates/five/template-parts/client-uploads.php';
}

 if ( leco_cp_can_mark_as_complete( $attributes, get_the_ID() ) ) {
     require LECO_CLIENT_PORTAL_DIR . '/templates/five/template-parts/mark-complete.php';
 }
