<?php
/**
 * Register Custom Blocks
 *
 * @package     LECO\Client_Portal\Blocks.
 * @since       4.12
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Filters the default array of categories for block types.
 *
 * @since 4.12
 *
 * @param array  $block_categories     Array of Block Categories.
 * @param string $block_editor_context (WP_Block_Editor_Context) The current block editor context.
 *
 * @return array
 */
function leco_cp_add_custom_gutenberg_category( $block_categories, $block_editor_context ) {
	if ( ! empty( $block_editor_context->post ) ) {
		return array_merge(
			$block_categories,
			[
				[
					'slug'  => 'leco-client-portal',
					'title' => esc_html__( 'Client Portal', 'leco-cp' ),
					'icon'  => '<svg xmlns="http://www.w3.org/2000/svg"  width="20px" height="20px" viewBox="0 0 264 264">
	<g fill="#a7aaad" fill-rule="evenodd" stroke="none" stroke-width="1">
		<g fill="#a7aaad" transform="translate(.004 .003)">
			<path d="M194.846 69.457l-58.17 58.17a6.61 6.61 0 01-9.35 0l-15.41-15.41a6.61 6.61 0 00-9.35 0l-15 15a6.6 6.6 0 000 9.34l39.79 39.79a6.61 6.61 0 009.35 0l82.55-82.55a6.61 6.61 0 000-9.35l-15-15a6.62 6.62 0 00-9.35-.07l-.06.08z"></path>
			<path d="M1.936 136.677l125.38 125.38a6.61 6.61 0 009.35 0l125.39-125.38a6.61 6.61 0 000-9.35l-15-15a6.61 6.61 0 00-9.35 0l-101 101a6.61 6.61 0 01-9.35 0l-76.67-76.65a6.61 6.61 0 010-9.35l76.63-76.63a6.61 6.61 0 019.35 0l15.42 15.4a6.61 6.61 0 009.35 0l15-15a6.61 6.61 0 000-9.35l-39.76-39.81a6.61 6.61 0 00-9.35 0L1.936 127.317a6.6 6.6 0 000 9.34v.02z"></path>
		</g>
	</g>
</svg>',
				],
			]
		);
	}

	return $block_categories;
}

add_filter( 'block_categories_all', 'leco_cp_add_custom_gutenberg_category', 10, 2 );

/**
 * Serverside Registration of Form Blocks.
 *
 * @since 4.12
 * @since 5.0  Added more blocks by parsing through the build/blocks folder.
 *
 * @return void
 */
function leco_cp_gutenberg_blocks() {
	register_block_type(
		LECO_CLIENT_PORTAL_DIR . 'build/blocks/login-block',
		array(
			'render_callback' => 'leco_cp_render_login_form',
		)
	);
	register_block_type( LECO_CLIENT_PORTAL_DIR . 'build/blocks/modules' );
	register_block_type( LECO_CLIENT_PORTAL_DIR . 'build/blocks/phases' );
	register_block_type( LECO_CLIENT_PORTAL_DIR . 'build/blocks/project-status-blocks' );
	register_block_type( LECO_CLIENT_PORTAL_DIR . 'build/blocks/project-status' );
	register_block_type( LECO_CLIENT_PORTAL_DIR . 'build/blocks/search-bar' );
	register_block_type( LECO_CLIENT_PORTAL_DIR . 'build/blocks/dashboard-link' );
	register_block_type( LECO_CLIENT_PORTAL_DIR . 'build/blocks/logout-link' );
	register_block_type( LECO_CLIENT_PORTAL_DIR . 'build/blocks/all-project-link' );
	register_block_type( LECO_CLIENT_PORTAL_DIR . 'build/blocks/header-logo' );
	register_block_type( LECO_CLIENT_PORTAL_DIR . 'build/blocks/general-information' );

	$options = get_option( 'leco_cp_options' );

	wp_localize_script( 'leco-cp-general-information-editor-script', 'leco_cp_options', $options );

	$icon_meta = array_values( json_decode( file_get_contents( LECO_CLIENT_PORTAL_DIR . '/assets/icon/caviar.json' ), true ) );
	$icons     = array_values( $icon_meta[4] );
	$file      = wp_list_pluck( $icons, 'file' );
	$caviar_options = array_combine( array_map( 'leco_cp_remove_dotsvg', $file ), wp_list_pluck( $icons, 'name' ) );

	$default_options = array(
		'bespoke'  => esc_html__( 'About', 'leco-cp' ),
		'blog'     => esc_html__( 'Branding', 'leco-cp' ),
		'content'  => esc_html__( 'Content', 'leco-cp' ),
		'cost'     => esc_html__( 'Payments', 'leco-cp' ),
		'feedback' => esc_html__( 'Feedback', 'leco-cp' ),
		'finding'  => esc_html__( 'Inspiration', 'leco-cp' ),
		'graphics' => esc_html__( 'Wireframes', 'leco-cp' ),
		'hiring'   => esc_html__( 'Taxes', 'leco-cp' ),
		'nothappy' => esc_html__( 'Receipts', 'leco-cp' ),
		'promote'  => esc_html__( 'Proposal', 'leco-cp' ),
		'quote'    => esc_html__( 'Quote', 'leco-cp' ),
		'role'     => esc_html__( 'Terms', 'leco-cp' ),
		'seo'      => esc_html__( 'Design', 'leco-cp' ),
		'social'   => esc_html__( 'Social', 'leco-cp' ),
		'testing'  => esc_html__( 'Development', 'leco-cp' ),
	);

	$icon_meta = array_values( json_decode( file_get_contents( LECO_CLIENT_PORTAL_DIR . '/assets/icon/caviar.json' ), true ) );
	$icons     = array_values( $icon_meta[4] );
	$file      = wp_list_pluck( $icons, 'file' );

	$icons = array_merge( $default_options, $caviar_options );

	$leco_cp_options = get_option( 'leco_cp_options' );

	$modules = array(
		'assetsUrl'              => LECO_CLIENT_PORTAL_URL . 'templates/five/assets/',
		'iconURL'                => LECO_CLIENT_PORTAL_URL . 'assets/icon/',
		'icons'                  => $icons,
		'adminURL'               => admin_url(),
		'siteShowMarkAsComplete' => isset( $leco_cp_options['show_mark_as_complete'] ) ? $leco_cp_options['show_mark_as_complete'] : 'show_with_due_date',
	);
	wp_localize_script( 'leco-cp-modules-script', 'lecoCpModules', $modules );

	// Register Block.
	register_block_type(
		LECO_CLIENT_PORTAL_DIR . 'build/blocks/register-block',
		array(
			'render_callback' => 'leco_cp_render_register_form',
		)
	);
}

add_action( 'init', 'leco_cp_gutenberg_blocks' );

/**
 * Removes Client Portal Blocks everywhere except leco_client CPT.
 * From: https://rudrastyh.com/gutenberg/remove-default-blocks.html
 *
 * @since 5.0
 *
 * @param bool|string[]           $allowed_blocks Array of block type slugs, or boolean to enable/disable all.
 *                                                Default true (all registered block types supported).
 * @param WP_Block_Editor_Context $editor_context The current block editor context.
 *
 * @return bool|string[]
 */
function leco_cp_remove_blocks_other_post_types( $allowed_blocks, $editor_context ) {
	if ( isset( $editor_context->post ) && 'leco_client' === $editor_context->post->post_type ) {
		return $allowed_blocks;
	}

	// get all the registered blocks
	$blocks = WP_Block_Type_Registry::get_instance()->get_all_registered();

	// then disable some of them
	unset( $blocks['leco-cp/modules'] );
	unset( $blocks['leco-cp/phases'] );
	unset( $blocks['leco-cp/project-status'] );
	unset( $blocks['leco-cp/project-status-block'] );
	unset( $blocks['leco-cp/search-bar'] );
	unset( $blocks['leco-cp/dashboard-link'] );
	unset( $blocks['leco-cp/logout-link'] );
	unset( $blocks['leco-cp/all-projects-link'] );
	unset( $blocks['leco-cp/header-logo'] );
	unset( $blocks['leco-cp/general-information'] );

	// return the new list of allowed blocks
	return array_keys( $blocks );
}

add_filter( 'allowed_block_types_all', 'leco_cp_remove_blocks_other_post_types', 10, 2 );

/**
 * Add Localize Scripts after wp query has run to access the post ID.
 *
 * @return void
 */
function leco_localize_scripts() {
	$fe_scripts = array(
		'_wpnonce'           => wp_create_nonce( 'leco_cp_ajax_nonce' ),
		'post_id'            => get_the_ID(),
		'ajaxurl'            => admin_url( 'admin-ajax.php', 'relative' ),
		'max_upload_size'    => esc_html( size_format( wp_max_upload_size() ) ),
	);

	wp_localize_script( 'leco-cp-modules-view-script', 'lecoCPVars', $fe_scripts );
}

add_action( 'wp', 'leco_localize_scripts' );

/**
 * Load Gutenberg Block Script and CSS in the Backend.
 *
 * @since  4.12
 *
 * @return void
 */
function leco_cp_gutenberg_blocks_scripts() {

	global $typenow;

	if ( 'leco_client' !== $typenow ) {
		return;
	}

	wp_enqueue_style( 'leco-cp-google-fonts', '//fonts.googleapis.com/css?family=Open+Sans:400,300,600,700,800&display=swap', array(), LECO_CLIENT_PORTAL_VER );

	$assets = include LECO_CLIENT_PORTAL_DIR . '/build/plugins/index.asset.php';

	wp_enqueue_script(
		'leco-cp-gutenberg-plugins',
		LECO_CLIENT_PORTAL_URL . 'build/plugins/index.js',
		$assets['dependencies'],
		LECO_CLIENT_PORTAL_VER
	);

}

add_action( 'enqueue_block_editor_assets', 'leco_cp_gutenberg_blocks_scripts' );
