<?php
/**
 * Client Portal Meta.
 *
 * @package     LECO\Client_Portal\Meta.
 * @since       5.0.0
 */

/**
 * Register Client Portal Meta.
 *
 * @return void
 */
function leco_cp_register_meta() {
	$prefix = 'leco_cp_5_';

	register_post_meta(
		'leco_client',
		$prefix . 'fallback_values',
		array(
			'show_in_rest'      => true,
			'single'            => true,
			'type'              => 'boolean',
			'sanitize_callback' => 'rest_sanitize_boolean',
			'default'           => leco_cp_get_option( 'fallback_values', true ),
			'auth_callback'     => leco_cp_auth_callback(),
		)
	);

	register_post_meta(
		'leco_client',
		$prefix . 'primary_color',
		array(
			'show_in_rest'      => true,
			'single'            => true,
			'type'              => 'string',
			'sanitize_callback' => 'sanitize_text_field',
			'default'           => leco_cp_get_option( 'primary_color', '#52cdf5' ),
			'auth_callback'     => leco_cp_auth_callback(),
		)
	);

	register_post_meta(
		'leco_client',
		$prefix . 'primary_text_color',
		array(
			'show_in_rest'      => true,
			'single'            => true,
			'type'              => 'string',
			'sanitize_callback' => 'sanitize_text_field',
			'default'           => leco_cp_get_option( 'primary_text_color', '#ffffff' ),
			'auth_callback'     => leco_cp_auth_callback(),
		)
	);

	register_post_meta(
		'leco_client',
		$prefix . 'secondary_color',
		array(
			'show_in_rest'      => true,
			'single'            => true,
			'type'              => 'string',
			'sanitize_callback' => 'sanitize_text_field',
			'default'           => leco_cp_get_option( 'secondary_color', '#ff5f5f' ),
			'auth_callback'     => leco_cp_auth_callback(),
		)
	);

	register_post_meta(
		'leco_client',
		$prefix . 'secondary_text_color',
		array(
			'show_in_rest'      => true,
			'single'            => true,
			'type'              => 'string',
			'sanitize_callback' => 'sanitize_text_field',
			'default'           => leco_cp_get_option( 'secondary_text_color', '#ffffff' ),
			'auth_callback'     => leco_cp_auth_callback(),
		)
	);

	register_post_meta(
		'leco_client',
		$prefix . 'tertiary_color',
		array(
			'show_in_rest'      => true,
			'single'            => true,
			'type'              => 'string',
			'sanitize_callback' => 'sanitize_text_field',
			'default'           => leco_cp_get_option( 'tertiary_color', '#3c5063' ),
			'auth_callback'     => leco_cp_auth_callback(),
		)
	);

	register_post_meta(
		'',
		$prefix . 'tertiary_text_color',
		array(
			'show_in_rest'      => true,
			'single'            => true,
			'type'              => 'string',
			'sanitize_callback' => 'sanitize_text_field',
			'default'           => leco_cp_get_option( 'tertiary_text_color', '#ffffff' ),
			'auth_callback'     => leco_cp_auth_callback(),
		)
	);

	register_post_meta(
		'leco_client',
		$prefix . 'show_mark_as_complete',
		array(
			'show_in_rest'      => true,
			'single'            => true,
			'type'              => 'string',
			'sanitize_callback' => 'sanitize_text_field',
			'default'           => leco_cp_get_option( 'show_mark_as_complete', 'show_with_due_date' ),
			'auth_callback'     => leco_cp_auth_callback(),
		)
	);

	register_post_meta(
		'leco_client',
		$prefix . 'public_portal',
		array(
			'show_in_rest'      => true,
			'single'            => true,
			'type'              => 'boolean',
			'sanitize_callback' => 'rest_sanitize_boolean',
			'default'           => false,
			'auth_callback'     => leco_cp_auth_callback(),
		)
	);

	register_post_meta(
		'leco_client',
		'leco_cp_client',
		array(
			'show_in_rest'      => true,
			'single'            => false,
			'type'              => 'integer',
			'sanitize_callback' => 'absint',
			'auth_callback'     => leco_cp_auth_callback(),
		)
	);

}

add_action( 'rest_api_init', 'leco_cp_register_meta' );

/**
 * Auth Callback Function
 *
 * @return bool
 */
function leco_cp_auth_callback() {
	return current_user_can( 'edit_posts' );
}
