<?php
/**
 * Customize the color palette.
 *
 * @since       5.0
 * @package     LECO\Client_Portal\Palette.
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Apply theme.json filters.
 *
 * @since 5.0
 *
 * @return void
 */
function leco_cp_apply_theme_json_theme_filters() {

	if ( ! wp_theme_has_theme_json() ) {
		return;
	}

	// Check to make sure the theme has a theme.json file and is a leco_client post type.
	$post_type    = isset( $_GET['post_type'] ) ? sanitize_text_field( wp_unslash( $_GET['post_type'] ) ) : false;
	$post_id      = isset( $_GET['post'] ) ? absint( wp_unslash( $_GET['post'] ) ) : false;
	$post_id_fe   = isset( $_SERVER['REQUEST_URI'] ) ? url_to_postid( esc_url_raw( wp_unslash( $_SERVER['REQUEST_URI'] ) ) ) : false;
	$post_type_fe = get_post_type( $post_id_fe ) ? get_post_type( $post_id_fe ) : false;

	if (
		( $post_type_fe === 'leco_client' ) ||
		( $post_type === 'leco_client' ) ||
		( $post_id !== false && get_post_type( $post_id ) === 'leco_client' ) ||
		leco_cp_is_patterns_page()
	) {
		add_filter( 'wp_theme_json_data_theme', 'leco_cp_wp_theme_json_data_theme' );
	}
}

add_action( 'init', 'leco_cp_apply_theme_json_theme_filters' );


/**
 * Replace the main theme.json with theme.json from the LECO Client Portal.
 * Filter to replace Primary, Secondary and Tertiary colors.
 *
 * @since 5.0
 *
 * @param WP_Theme_JSON_Data $json_data Class to access and update the underlying data.
 *
 * @return WP_Theme_JSON_Data
 */
function leco_cp_wp_theme_json_data_theme( $json_data ) {

	$id = isset( $_GET['post'] ) ? intval( $_GET['post'] ) : null;

	$theme_json = $json_data->get_data();

	$palette = isset( $theme_json['settings']['color']['palette']['theme'] ) ? $theme_json['settings']['color']['palette']['theme'] : array();

	$prefix          = 'leco_cp_5_';
	$primary_color   = get_post_meta( $id, $prefix . 'primary_color', true ) ? get_post_meta( $id, $prefix . 'primary_color', true ) : leco_cp_get_option( 'primary_color', '#52cdf5' );
	$secondary_color = get_post_meta( $id, $prefix . 'secondary_color', true ) ? get_post_meta( $id, $prefix . 'secondary_color', true ) : leco_cp_get_option( 'secondary_color', '#ff5f5f' );
	$tertiary_color  = get_post_meta( $id, $prefix . 'tertiary_color', true ) ? get_post_meta( $id, $prefix . 'tertiary_color', true ) : leco_cp_get_option( 'tertiary_color', '#3c5063' );

	$leco_cp_theme = json_decode( file_get_contents( LECO_CLIENT_PORTAL_DIR . '/includes/gutenberg/theme.json' ), true );
	$leco_cp_theme_data  = new WP_Theme_JSON_Data( $leco_cp_theme, 'theme' );

	$new_data = array(
		'version'  => 2,
		'settings' => array(
			'color' => array(
				'palette' =>
					array_merge(
						array(
							array(
								'name'  => 'CP Primary',
								'slug'  => 'leco-cp-primary',
								'color' => $primary_color,
							),
							array(
								'name'  => 'CP Secondary',
								'slug'  => 'leco-cp-secondary',
								'color' => $secondary_color,
							),
							array(
								'name'  => 'CP Tertiary',
								'slug'  => 'leco-cp-tertiary',
								'color' => $tertiary_color,
							),
						),
						$palette
					),
			),
		),
	);

	$leco_cp_theme_data->update_with( $new_data );

	return $leco_cp_theme_data;

}
