<?php
/**
 * Add block patterns.
 *
 * @since       5.0
 * @package     LECO\Client_Portal\Patterns.
 */

/**
 * Register block patterns.
 *
 * @since 5.0
 *
 * @return void
 */
function leco_register_block_patterns() {
	register_block_pattern_category(
		'leco-client-portal',
		array(
			'label' => esc_html__( 'Client Portal', 'leco-cp' ),
		)
	);

	register_block_pattern(
		'leco-cp/header',
		array(
			'title'       => esc_html__( 'Header', 'leco-cp' ),
			'description' => esc_html__( 'Display a header in your Client Portal', 'leco-cp' ),
			'content'     => leco_cp_get_pattern_by_path( 'templates/five/patterns/header.php' ),
			'categories'  => array(
				'leco-client-portal',
			),
			'postTypes' => array( 'leco_client' ),
		)
	);

	register_block_pattern(
		'leco-cp/call-to-action',
		array(
			'title'       => esc_html__( 'Call To Action', 'leco-cp' ),
			'description' => esc_html__( 'The Call To Action section is consisted with a short paragraph and a clickable button.', 'leco-cp' ),
			'content'     => leco_cp_get_pattern_by_path( 'templates/five/patterns/call-to-action.php' ),
			'categories'  => array(
				'leco-client-portal',
			),
			'postTypes' => array( 'leco_client' ),
		)
	);

	register_block_pattern(
		'leco-cp/general-information',
		array(
			'title'       => esc_html__( 'General Information', 'leco-cp' ),
			'description' => esc_html__( 'General Information', 'leco-cp' ),
			'inserter'    => false,
			'content'     => leco_cp_get_pattern_by_path( 'templates/five/patterns/general-information.php' ),
			'categories'  => array(
				'leco-client-portal',
			),
			'postTypes' => array( 'leco_client' ),
		)
	);

	register_block_pattern(
		'leco-cp/project-status',
		array(
			'title'       => esc_html__( 'Show project status', 'leco-cp' ),
			'description' => esc_html__( 'Project Information - Show project status', 'leco-cp' ),
			'content'     => leco_cp_get_pattern_by_path( 'templates/five/patterns/project-status.php' ),
			'categories'  => array(
				'leco-client-portal',
			),
			'postTypes' => array( 'leco_client' ),
		)
	);

	register_block_pattern(
		'leco-cp/phases-blocks',
		array(
			'title'       => esc_html__( 'Phases Boxes', 'leco-cp' ),
			'description' => esc_html__( 'Project Information - Show phases', 'leco-cp' ),
			'content'     => leco_cp_get_pattern_by_path( 'templates/five/patterns/phases-blocks.php' ),
			'categories'  => array(
				'leco-client-portal',
			),
			'postTypes' => array( 'leco_client' ),
		)
	);

	register_block_pattern(
		'leco-cp/footer-contact',
		array(
			'title'       => esc_html__( 'Footer Contact', 'leco-cp' ),
			'description' => esc_html__( 'Contact information found in the footer', 'leco-cp' ),
			'content'     => leco_cp_get_pattern_by_path( 'templates/five/patterns/footer-contacts.php' ),
			'categories'  => array(
				'leco-client-portal',
			),
			'postTypes' => array( 'leco_client' ),
		)
	);
}

add_action( 'init', 'leco_register_block_patterns' );
