<?php
/**
 * Post Type Template
 *
 * @package     LECO\Client_Portal\CPT_Template.
 * @since       5.0
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Adds gutenberg template to a new post
 *
 * @since 5.0
 *
 * @return array
 */
function leco_cp_post_type_template(): array {
	return array(
		array(
			'core/pattern',
			array(
				'slug' => 'leco-cp/header',
			),
		),
		array(
			'core/pattern',
			array(
				'slug' => 'leco-cp/general-information',
			),
		),
		array(
			'core/pattern',
			array(
				'slug' => 'leco-cp/project-status',
			),
		),
		array(
			'core/pattern',
			array(
				'slug' => 'leco-cp/phases-blocks',
			),
		),
		array(
			'core/pattern',
			array(
				'slug' => 'leco-cp/call-to-action',
			),
		),
		array(
			'core/pattern',
			array(
				'slug' => 'leco-cp/footer-contact',
			),
		),
	);
}

/**
 * Adds inline styles for the leco_client post type on the frontend and admin
 *
 * @since 5.0
 *
 * @return void
 */
function leco_cp_add_inline_styles() {

	global $typenow;

	if ( 'leco_client' !== $typenow && ! is_singular( 'leco_client' ) ) {
		return;
	}

	if ( is_page( 'client-portal-login' ) ) {
		$fallback = 'yes';
	} else {
		$fallback = get_post_meta( get_the_ID(), 'leco_cp_fallback_values', true );
	}
	if ( empty( $fallback ) ) {
		$fallback = leco_cp_get_option( 'fallback_values', 'yes' );
	}
	global $leco_cp_is_fallback;
	$leco_cp_is_fallback = ( 'yes' === $fallback ) ? true : false;

	$prefix = 'leco_cp_5_';

	// Get colors from project settings.
	$post_pc  = get_post_meta( get_the_ID(), $prefix . 'primary_color', true );
	$post_ptc = get_post_meta( get_the_ID(), $prefix . 'primary_text_color', true );
	$post_sc  = get_post_meta( get_the_ID(), $prefix . 'secondary_color', true );
	$post_stc = get_post_meta( get_the_ID(), $prefix . 'secondary_text_color', true );
	$post_tc  = get_post_meta( get_the_ID(), $prefix . 'tertiary_color', true );
	$post_ttc = get_post_meta( get_the_ID(), $prefix . 'tertiary_text_color', true );

	// Get colors from CP settings.
	$pc  = ( empty( $post_pc ) && $leco_cp_is_fallback ) ? leco_cp_get_option( 'primary_color', '#52cdf5' ) : $post_pc;
	$ptc = ( empty( $post_ptc ) && $leco_cp_is_fallback ) ? leco_cp_get_option( 'primary_text_color', '#ffffff' ) : $post_ptc;
	$sc  = ( empty( $post_sc ) && $leco_cp_is_fallback ) ? leco_cp_get_option( 'secondary_color', '#ff5f5f' ) : $post_sc;
	$stc = ( empty( $post_stc ) && $leco_cp_is_fallback ) ? leco_cp_get_option( 'secondary_text_color', '#ffffff' ) : $post_stc;
	$tc  = ( empty( $post_tc ) && $leco_cp_is_fallback ) ? leco_cp_get_option( 'tertiary_color', '#3c5063' ) : $post_tc;
	$ttc = ( empty( $post_ttc ) && $leco_cp_is_fallback ) ? leco_cp_get_option( 'tertiary_text_color', '#ffffff' ) : $post_ttc;

	printf(
		'<style> %s {
			--wp--preset--color--leco-cp-primary: %s;
			--wp--preset--color--leco-cp-primary-text: %s;
			--wp--preset--color--leco-cp-secondary: %s;
			--wp--preset--color--leco-cp-secondary-text: %s;
			--wp--preset--color--leco-cp-tertiary: %s;
			--wp--preset--color--leco-cp-tertiary-text: %s;
		} </style>',
		is_admin() ? '.editor-styles-wrapper' : '.leco_client-template-default',
		esc_attr( ( empty( $pc ) ) ? 'transparent' : $pc ),
		esc_attr( ( empty( $ptc ) ) ? 'transparent' : $ptc ),
		esc_attr( ( empty( $sc ) ) ? 'transparent' : $sc ),
		esc_attr( ( empty( $stc ) ) ? 'transparent' : $stc ),
		esc_attr( ( empty( $tc ) ) ? 'transparent' : $tc ),
		esc_attr( ( empty( $ttc ) ) ? 'transparent' : $ttc )
	);
}

add_action( 'leco_cp_template_inline_styles', 'leco_cp_add_inline_styles' );

add_action( 'admin_head', 'leco_cp_add_inline_styles' );
