import { rawHandler, createBlock } from '@wordpress/blocks';
import { dispatch, useSelect, subscribe, select } from '@wordpress/data';

export default function Edit( props ) {
	const { attributes, setAttributes, clientId } = props;
	const { insertBlocks } = attributes;

	const defaultGeneralInformation = `Hello and welcome! Here you can find everything you need during our project from all your files to how to contact me. You\'ll have full access to this area throughout the whole project and for 6 months after completion. However all of your files will still live on in <a href="#">your project folder.</a>
<h2>How to contact me</h2>
If you have any small questions or comments throughout the project, you can <a class="email" href="mailto:#">email me.</a> For anything larger it\'s best to wait until our next catch up call so we can go through it properly. Our call is scheduled for every <strong>[date-time]</strong>
<h2>Availability</h2>
My working week is <strong>[your-working-hours]</strong>

Occasionally I take time off for holidays so if this is due to happen during our project I will let you know in good time. Other than that you can expect intermittent availability around all major holidays including Christmas, New Year, Easter and (ok, not a major holiday) my birthday - [your-birthday-if-you-like]`;

	const GeneralInformation = leco_cp_options?.general_information ? leco_cp_options?.general_information : defaultGeneralInformation;

	const convertToBlocks = ( html ) => {
		if ( ! html ) {
			return {};
		}
		return rawHandler( {
			HTML: html,
		} );
	};

	const { index } = useSelect( ( selects ) => {
		const { getBlockIndex } = selects( 'core/block-editor' );
		return {
			index: getBlockIndex( clientId ),
		};
	} );

	const maybeInsertBlocks = ( blocks ) => {
		if ( ! insertBlocks || ! blocks ) {
			return;
		}

		const groupBlock = createBlock(
			'core/group', { className: 'content-section' }, blocks
		);

		dispatch( 'core/block-editor' ).insertBlock( groupBlock, index );

		// Make sure we don't insert the blocks again.
		setAttributes( { insertBlocks: false } );

		dispatch( 'core/block-editor' ).removeBlock( clientId );
	};

	const blocks = convertToBlocks( GeneralInformation );

	const closeListener = subscribe( () => {
		const isReady = select( 'core/editor' ).__unstableIsEditorReady();
		if ( ! isReady ) {
			return;
		}
		// Close the listener as soon as we know we are ready to avoid an infinite loop.
		closeListener();

		maybeInsertBlocks( blocks );
	} );

	return (
		<></>
	);
}
