/**
 * External dependencies
 */
import classnames from 'classnames';

/**
 * Internal dependencies
 */
import { __ } from '@wordpress/i18n';

import {
	useBlockProps,
	MediaPlaceholder,
	InspectorControls,
	BlockControls,
	MediaReplaceFlow,
} from '@wordpress/block-editor';

import { ToggleControl, PanelBody, TextControl } from '@wordpress/components';

import { useDispatch } from '@wordpress/data';

import { store as noticesStore } from '@wordpress/notices';

export default function Edit( props ) {
	const blockProps = useBlockProps();
	const { attributes, setAttributes } = props;
	const { logo, fixedWidth, width } = attributes;

	const classes = classnames( 'project-logo' );

	const ALLOWED_MEDIA_TYPES = [ 'image' ];

	const { createErrorNotice } = useDispatch( noticesStore );

	const onSelectImage = ( el ) => {
		setAttributes( { logo: el } );
	};

	const onUploadError = ( message ) => {
		createErrorNotice( message, { type: 'snackbar' } );
		setAttributes( {
			logo: undefined,
		} );
	};

	return (
		<>
			<InspectorControls>
				<PanelBody
					title={ __( 'Logo Settings', 'leco-cp' ) }
					initialOpen={ true }
				>
					<ToggleControl
						label={ __( 'Fixed logo width', 'leco-cp' ) }
						checked={ fixedWidth }
						onChange={ () => {
							setAttributes( { fixedWidth: ! fixedWidth } );
						} }
						help={
							fixedWidth
								? __( 'Make logo image fixed width', 'leco-cp' )
								: __( 'Make logo image width 100%.', 'leco-cp' )
						}
					/>
					{ fixedWidth && (
						<TextControl
							label={ __( 'Logo Width (px)', 'leco-cp' ) }
							value={ width }
							type="number"
							onChange={ ( value ) =>
								setAttributes( { width: Number( value ) } )
							}
						/>
					) }
				</PanelBody>
			</InspectorControls>
			<BlockControls group="other">
				<MediaReplaceFlow
					mediaId={ logo?.id }
					mediaURL={ logo?.url }
					allowedTypes={ ALLOWED_MEDIA_TYPES }
					accept="image/*"
					onSelect={ onSelectImage }
					onError={ onUploadError }
				/>
			</BlockControls>
			<div { ...blockProps }>
				{ logo ? (
					<img
						src={ logo.url }
						alt={ logo.alt }
						className={ classes }
						style={ {
							width: fixedWidth ? width + 'px' : 'auto',
						} }
					/>
				) : (
					<MediaPlaceholder
						onSelect={ onSelectImage }
						allowedTypes={ ALLOWED_MEDIA_TYPES }
						multiple={ false }
						labels={ { title: 'Add Logo' } }
					></MediaPlaceholder>
				) }
			</div>
		</>
	);
}
