/* WordPress dependencies */
import apiFetch from '@wordpress/api-fetch';
import { useDispatch } from '@wordpress/data';
import { Modal, Button } from '@wordpress/components';
import { useState, useEffect } from '@wordpress/element';

/* External dependencies */
import {
	DndContext,
	closestCenter,
	KeyboardSensor,
	PointerSensor,
	useSensor,
	useSensors,
} from '@dnd-kit/core';

import {
	arrayMove,
	SortableContext,
	sortableKeyboardCoordinates,
	verticalListSortingStrategy,
} from '@dnd-kit/sortable';

/* Internal dependencies */
import SortableItem from './SortableItem';
import UploadsModal from './UploadsModal';

/* Component */
const SortableList = ( {
	moduleFiles,
	setFiles,
	clientUploads,
	phaseID,
	postID,
	setIsDeleting,
} ) => {
	const sensors = useSensors(
		useSensor( PointerSensor ),
		useSensor( KeyboardSensor, {
			coordinateGetter: sortableKeyboardCoordinates,
		} )
	);

	const handleRemove = ( { index } ) => {
		const newFiles = moduleFiles.filter( ( item, i ) => i !== index );
		setFiles( newFiles );
	};

	const [ modelOpen, setModelOpen ] = useState( false );
	const [ fileToDelete, setFileToDelete ] = useState( null );

	const setAlert = ( props ) => {
		setModelOpen( true );
		setFileToDelete( props );
	};

	const removeFileWordpress = async ( props ) => {
		const { index, name } = props;

		setModelOpen( false );

		await apiFetch( {
			path: `leco-cp/v1/update-module/`,
			method: 'POST',
			data: {
				phaseID,
				postID,
				file: name,
				action: 'delete_client_uploads',
			},
		} )
			.then( ( success ) => {
				setIsDeleting( true );
				handleRemove( { index } );
			} )
			.catch( ( error ) => {
				console.log( error );
			} );
	};

	function handleDragEnd( event ) {
		const { active, over } = event;

		if ( active.id !== over.id ) {
			setFiles( ( items ) => {
				const oldIndex = items.findIndex(
					( item ) => item.id === active.id
				);
				const newIndex = items.findIndex(
					( item ) => item.id === over.id
				);

				return arrayMove( items, oldIndex, newIndex );
			} );
		}
	}

	return (
		<div>
			{ modelOpen && (
				<UploadsModal
					setModelOpen={ setModelOpen }
					deleteFile={ removeFileWordpress }
					file={ fileToDelete }
					isBE={ true }
				/>
			) }

			{ moduleFiles && (
				<DndContext
					sensors={ sensors }
					collisionDetection={ closestCenter }
					onDragEnd={ handleDragEnd }
				>
					<SortableContext
						items={ moduleFiles }
						strategy={ verticalListSortingStrategy }
					>
						{ moduleFiles.map( ( file, index ) => {
							return (
								<SortableItem
									phaseID={ phaseID }
									key={ index }
									id={ file.id }
									order={ index }
									file={ file }
									onRemove={
										clientUploads ? setAlert : handleRemove
									}
								/>
							);
						} ) }
					</SortableContext>
				</DndContext>
			) }
		</div>
	);
};

export default SortableList;
