/* WordPress dependencies */
import { __ } from '@wordpress/i18n';
import { useState, useEffect } from '@wordpress/element';
import { select, useDispatch } from '@wordpress/data';

/* Internal dependencies */
import SortableList from '../components/SortableList';

const ClientUploadsModule = ( props ) => {
	const { attributes, setAttributes } = props;
	const { moduleClientUploads, phaseID } = attributes;

	const [ files, setFiles ] = useState( moduleClientUploads );
	const [ postID, setPostID ] = useState( 0 );
	const [ isDeleting, setIsDeleting ] = useState( false );

	const { savePost } = useDispatch( 'core/editor' );

	useEffect( () => {
		const { getCurrentPostId } = select( 'core/editor' );
		setPostID( getCurrentPostId );

		setAttributes( { moduleClientUploads: files } );

		// Make sure this doesn't happen on initial load or if shuffling files
		if ( ! isDeleting ) {
			return;
		}

		// need to save the post because if the user does not save it after deletion,
		// the image data will still appear in the attributes, but the image href will no-longer work
		// because it's been deleted from the server
		savePost();
		setIsDeleting( false );
	}, [ setAttributes, files, savePost, isDeleting ] );

	return (
		<div>
			{ files.length > 0 ? (
				<SortableList
					setFiles={ setFiles }
					moduleFiles={ files }
					clientUploads={ true }
					phaseID={ phaseID }
					postID={ postID }
					setIsDeleting={ setIsDeleting }
				/>
			) : (
				<p>{ __( 'Uploaded files will appear here' ) }</p>
			) }
		</div>
	);
};

export default ClientUploadsModule;
