import { __ } from '@wordpress/i18n';
import apiFetch from '@wordpress/api-fetch';
import { useEffect, useState } from '@wordpress/element';
import { SelectControl, Spinner, Button } from '@wordpress/components';
import { select } from '@wordpress/data';
import { isURL } from '@wordpress/url';

const ContentPageModule = ( props ) => {
	const [ posts, setPosts ] = useState( [] );
	const [ postID, setPostID ] = useState();
	const [ siteURL, setSiteURL ] = useState();
	const { attributes, setAttributes } = props;
	const { title, description, moduleContentPage } = attributes;
	const { permalink, _wpnonce } = lecoCPAdminVars;

	useEffect( () => {
		apiFetch( { path: '/wp/v2/leco_content_page' } ).then(
			( contentPages ) => {
				const selectArray = contentPages.map( ( contentPage ) => ( {
					value: contentPage.id,
					label: contentPage.title.rendered,
				} ) );

				selectArray.unshift( {
					value: 0,
					label: __( 'Create new', 'leco-cp' ),
				} );

				setPosts( selectArray );
			}
		);

		const currentID = select( 'core/editor' ).getCurrentPostId();
		setPostID( currentID );

		const currentSiteURL = select( 'core' ).getSite().url;
		setSiteURL( currentSiteURL );
	}, [ moduleContentPage ] );

	if ( posts.length === 0 ) {
		return <Spinner />;
	}

	const createNewPost = () => {
		apiFetch( {
			path: '/wp/v2/leco_content_page',
			method: 'POST',
			data: {
				title,
				content: `<!-- wp:paragraph --><p>${ description }</p><!-- /wp:paragraph -->`,
				status: 'publish',
			},
		} ).then( ( res ) => {
			setAttributes( { moduleContentPage: res.id } );
		} );
	};

	const previewPost = () => {
		const data = new FormData();

		data.append( 'action', 'leco_cp_get_permalink' );
		data.append( 'post_id', moduleContentPage );
		data.append( 'permalink', permalink );
		data.append( '_wpnonce', _wpnonce );

		fetch( siteURL + ajaxurl, {
			method: 'POST',
			credentials: 'same-origin',
			body: data,
		} )
			.then( ( response ) => {
				return response.json();
			} )
			.then( ( result ) => {
				if ( isURL( result ) ) {
					window.open( result, '_blank' );
				}
			} );
	};

	const editPost = () => {
		const url = `post.php?post=${ moduleContentPage }&action=edit&parent_id=${ postID }`;
		window.open( url, '_blank' );
	};

	return (
		<div>
			<SelectControl
				label={ __( 'Select a page', 'leco-cp' ) }
				value={ moduleContentPage }
				onChange={ ( page ) =>
					setAttributes( { moduleContentPage: Number( page ) } )
				}
				options={ posts }
			/>
			{ moduleContentPage === 0 ? (
				<Button variant="primary" onClick={ createNewPost }>
					{ __( 'Create New Post', 'leco-cp' ) }
				</Button>
			) : (
				<div className="content-page__btns">
					<Button variant="secondary" onClick={ previewPost }>
						{ __( 'Preview', 'leco-cp' ) }
					</Button>
					<Button variant="secondary" onClick={ editPost }>
						{ __( 'Edit', 'leco-cp' ) }
					</Button>
				</div>
			) }
		</div>
	);
};

export default ContentPageModule;
