import { __ } from '@wordpress/i18n';
import { TextControl, Button } from '@wordpress/components';

const URLModule = ( props ) => {
	const { item, index, updateLink } = props;

	return (
		<>
			<TextControl
				label={ __( 'Add URL*', 'leco-cp' ) }
				value={ item.linkUrl }
				onChange={ ( updated ) =>
					updateLink( 'linkUrl', index, updated )
				}
				__nextHasNoMarginBottom={ true }
				type="url"
				required
			/>
			<TextControl
				label={ __( 'Add Text', 'leco-cp' ) }
				value={ item.linkTitle }
				onChange={ ( updated ) =>
					updateLink( 'linkTitle', index, updated )
				}
				__nextHasNoMarginBottom={ true }
			/>
		</>
	);
};

const LinksModule = ( props ) => {
	const { attributes, setAttributes } = props;
	const { moduleLinks } = attributes;

	const updateLink = ( type, index, updated ) => {
		const updatedLinks =
			moduleLinks.length === 0
				? [ { linkUrl: '', linkTitle: '' } ]
				: [ ...moduleLinks ];

		updatedLinks[ index ][ type ] = updated;

		setAttributes( { moduleLinks: updatedLinks } );
	};

	const addLink = () => {
		const updatedLinks = [ ...moduleLinks ];
		updatedLinks.push( { linkUrl: '', linkTitle: '' } );

		setAttributes( { moduleLinks: updatedLinks } );
	};

	const removeLink = ( index ) => {
		const updatedLinks = [ ...moduleLinks ];
		updatedLinks.splice( index, 1 );

		setAttributes( { moduleLinks: updatedLinks } );
	};

	return (
		<div>
			{ moduleLinks.length === 0 ? (
				<div className="links-container">
					<URLModule
						updateLink={ updateLink }
						item={ { linkUrl: '', linkTitle: '' } }
						index={ 0 }
					/>
				</div>
			) : (
				<>
					{ moduleLinks.map( ( item, index ) => {
						return (
							<div className="links-container" key={ index }>
								<URLModule
									updateLink={ updateLink }
									item={ item }
									index={ index }
								/>
								<Button
									variant="link"
									onClick={ () => removeLink( index ) }
								>
									{ __( 'Remove Link', 'leco-cp' ) }
								</Button>
							</div>
						);
					} ) }
				</>
			) }

			<Button
				className="add-new-link-btn"
				variant="primary"
				onClick={ addLink }
			>
				{ __( 'Add Link', 'leco-cp' ) }
			</Button>
		</div>
	);
};

export default LinksModule;
