/* WordPress dependencies */
import { __ } from '@wordpress/i18n';
import { useState, useEffect } from '@wordpress/element';
import { select } from '@wordpress/data';

/* Internal dependencies */
import ModulesMediaUpload from '../components/media-upload';
import SortableList from '../components/SortableList';

const PrivateFilesModule = ( props ) => {
	const { attributes, setAttributes } = props;
	const { modulePrivateFiles } = attributes;

	const [ files, setFiles ] = useState( modulePrivateFiles );
	const [ postID, setPostID ] = useState( 0 );

	useEffect( () => {
		const thePostId = select( 'core/editor' ).getCurrentPostId();

		setPostID( thePostId );

		setAttributes( { modulePrivateFiles: files } );
	}, [ setAttributes, files ] );

	const moduleFilesIDs = files?.map( ( file ) => file.id );

	const handleOnSelect = ( media ) => {
		const updatedMedia = [ ...media ];

		updatedMedia.forEach( ( item ) => {
			item.url =
				lecoCPAdminVars.permalink + // eslint-disable-line
				'file/' +
				btoa( postID + '|' + item.id ) +
				'/' +
				item.filename;
		} );

		setFiles( updatedMedia );
	};

	return (
		<div>
			<SortableList
				setFiles={ setFiles }
				moduleFiles={ files }
				clientUploads={ false }
			/>

			<ModulesMediaUpload
				values={ moduleFilesIDs }
				setMedia={ ( media ) => {
					handleOnSelect( media );
				} }
				btnTxt={ __( 'Add or Upload Files', 'leco-cp' ) }
				additionalData={ { params: { type: 'leco_private_file' } } }
				extraClass="leco_private_file"
			/>

			<p className="leco-cp__instructions">
				{ __(
					"Upload or add multiple attachments. Please note we currently don't support the following file types: jpg, jpeg, png, gif, mp3, ogg."
				) }
			</p>
		</div>
	);
};

export default PrivateFilesModule;
