import { createRoot } from '@wordpress/element';
import ClientUploadsModule from './module-types/client-uploads-fe';
import apiFetch from '@wordpress/api-fetch';

import MarkedCompleted from './components/completed';

let lightboxes;
let lecoCPLity;
let closeBtn;
let completeBtn;
let markAsCompleteBtn;

const openLightbox = ( event ) => {
	event.preventDefault();

	const target = event.currentTarget.getAttribute( 'href' );

	lecoCPLity = lity( target, {
		template:
			'<div class="lity" role="dialog" aria-label="Dialog Window (Press escape to close)" tabindex="-1"><div class="lity-wrap" data-lity-close role="document"><div class="lity-loader" aria-hidden="true">Loading...</div><div class="lity-container"><div class="lity-content"></div><button class="lity-close" type="button" aria-label="" data-lity-close><?xml version="1.0" encoding="utf-8" standalone="yes"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" version="1.1" id="Layer_1" x="0px" y="0px" viewBox="0 0 48 48" style="enable-background:new 0 0 48 48;" xml:space="preserve"><style type="text/css">\n' +
			'\t.st0{fill:none;stroke:#000000;stroke-width:2;stroke-miterlimit:10;}\n' +
			'</style><title></title><g id="Fail"><circle class="st0" cx="24" cy="24" r="23"></circle><g id="Cross"><line class="st0" x1="15" y1="15" x2="33" y2="33"></line><line class="st0" x1="15" y1="33" x2="33" y2="15"></line></g></g></svg></button></div></div></div>',
	} );

	closeBtn = document.querySelector( '.lity-close svg' );
	closeBtn.addEventListener( 'click', closeLightbox );
};

const closeLightbox = ( event ) => {
	event.preventDefault();
	lecoCPLity.close();
	removeEventListener( 'click', closeLightbox );
};

const eventListeners = () => {
	[ ...lightboxes ].forEach( ( lightbox ) => {
		lightbox.addEventListener( 'click', openLightbox );
	} );

	[ ...completeBtn ].forEach( ( btn ) => {
		btn.addEventListener( 'click', openLightbox );
	} );

	[ ...markAsCompleteBtn ].forEach( ( btn ) => {
		btn.addEventListener( 'click', markAsComplete );
	} );
};

const replaceMarkAsComplete = ( key ) => {
	const module = document.getElementById( key );
	const container = module.querySelector( '.checkbox-container' );
	const root = createRoot( container );

	root.render( <MarkedCompleted admin={ false } /> );

	lecoCPLity.close();
};

const markAsComplete = async ( event ) => {
	event.preventDefault();

	const btn = event.currentTarget;
	const key = btn.getAttribute( 'data-key' );
	const postID = btn.getAttribute( 'data-post-id' );
	const action = btn.getAttribute( 'data-action' );

	const response = await apiFetch( {
		path: `leco-cp/v1/update-module/`,
		method: 'POST',
		data: {
			key,
			postID,
			action,
		},
	} )
		.then( ( success ) => {
			replaceMarkAsComplete( key );
		} )
		.catch( ( error ) => {
			console.log( error );
		} );
};

const addUploadFiles = () => {
	const containers = document.getElementsByClassName(
		'leco-cp__file-upload-container'
	);

	[ ...containers ].forEach( ( container ) => {
		const module = container.closest( '.lity-hide' ).getAttribute( 'id' );
		const postID = container
			.closest( '.lity-hide' )
			.getAttribute( 'data-leco-cp-post-id' );
		const phaseID = container
			.closest( '.lity-hide' )
			.getAttribute( 'data-leco-cp-module-id' );
		const files = container
			.closest( '.lity-hide' )
			.getAttribute( 'data-leco-cp-files' );

		const root = createRoot( container );

		root.render(
			<ClientUploadsModule
				module={ module }
				postID={ postID }
				phaseID={ phaseID }
				files={ files }
			/>
		);
	} );
};

const maybeScrolltoID = () => {
	const hash = window.location.hash;
	if ( hash ) {
		const target = document.querySelector( hash );
		if ( target ) {
			target.scrollIntoView( {
				behavior: 'smooth',
				block: 'start',
			} );
		}
	}
};

const init = () => {
	lightboxes = document.querySelectorAll( '[data-leco-cp-lity]' );
	completeBtn = document.querySelectorAll(
		'[data-leco-cp-mark-as-complete]'
	);
	markAsCompleteBtn = document.querySelectorAll(
		'[data-leco-cp-confirm-delete]'
	);

	const hash = window.location.hash;
	if ( hash ) {
		const target = document.querySelector( hash );
		if ( target ) {
			target.scrollIntoView( {
				behavior: 'smooth',
				block: 'start',
			} );
		}
	}

	eventListeners();
	addUploadFiles();
	maybeScrolltoID();
};

addEventListener( 'load', ( event ) => {
	init();
} );
