/**
 * External dependencies
 */
import classnames from 'classnames';

/**
 * WordPress dependencies
 */
import { __ } from '@wordpress/i18n';

import {
	AlignmentControl,
	BlockControls,
	RichText,
	useBlockProps,
	InnerBlocks,
	InspectorControls,
} from '@wordpress/block-editor';

import { useEffect } from '@wordpress/element';

import { PanelBody, RangeControl } from '@wordpress/components';

import { useInstanceId } from '@wordpress/compose';

export default function PhasesEdit( props ) {
	const { attributes, setAttributes } = props;
	const { align, title, phase, uid, columns } = attributes;

	const ALLOWED_BLOCKS = [ 'leco-cp/modules' ];

	const TEMPLATE = [ [ 'leco-cp/modules' ] ];

	const instanceID = useInstanceId( PhasesEdit );

	useEffect( () => {
		setAttributes( { uid: instanceID } );
	}, [ instanceID ] );

	const blockProps = useBlockProps( {
		className: classnames( {
			[ `has-text-align-${ align }` ]: align,
		} ),
	} );

	const containerClasses = classnames( {
		[ `leco-cp-cols-${ columns }` ]: columns,
		'leco-cp-container': true,
	} );

	return (
		<div { ...blockProps }>
			<>
				<BlockControls group="block">
					<AlignmentControl
						value={ align }
						onChange={ ( newAlign ) =>
							setAttributes( {
								align: newAlign,
							} )
						}
					/>
				</BlockControls>
				<InspectorControls>
					<PanelBody title={ __( 'Settings', 'leco-cp' ) }>
						<RangeControl
							label={ __( 'Columns', 'leco-cp' ) }
							value={ columns }
							onChange={ ( value ) =>
								setAttributes( { columns: value } )
							}
							min={ 1 }
							max={ 5 }
						/>
					</PanelBody>
				</InspectorControls>
				<RichText
					tagName="span"
					value={ phase }
					onChange={ ( text ) => setAttributes( { phase: text } ) }
					placeholder={ __( 'Add phase text', 'leco-cp' ) }
					className="leco-cp-phase-text"
				/>
				<RichText
					tagName="h2"
					value={ title }
					onChange={ ( text ) => setAttributes( { title: text } ) }
					allowedFormats={ [ 'core/bold', 'core/italic' ] }
					placeholder={ __( 'Add a title', 'leco-cp' ) }
					className="phase-title"
				/>
				<div className={ containerClasses }>
					<InnerBlocks
						allowedBlocks={ ALLOWED_BLOCKS }
						template={ TEMPLATE }
						orientation="horizontal"
					/>
				</div>
			</>
		</div>
	);
}
