import { __ } from '@wordpress/i18n';
import { useBlockProps, RichText, InspectorControls } from '@wordpress/block-editor';
import { DatePicker, PanelBody, ToggleControl, RangeControl } from '@wordpress/components';
import { date as Date } from '@wordpress/date';

export default function Edit( props ) {
	const blockProps = useBlockProps();
	const { attributes, setAttributes } = props;
	const { value, label, date, showDate } = attributes;

	return (
		<>
			<InspectorControls>
				<PanelBody title={ __( 'Settings', 'leco-cp' ) }>
					<ToggleControl
						label={ __( 'Choose Phase Date', 'leco-cp' ) }
						help={
							showDate
								? __( 'Date', 'leco-cp' )
								: __( 'Text', 'leco-cp' )
						}
						checked={ showDate }
						onChange={ () => {
							setAttributes( { showDate: ! showDate } );
						} }
					/>
					{
						showDate && (
							<DatePicker
								currentDate={ date }
								onChange={ ( newDate ) => {
									setAttributes( { date: newDate } );
								} }
							/>
						)
					}
				</PanelBody>
			</InspectorControls>
			<div { ...blockProps }>
				{
					showDate ? (
						<span className="value">
							{ Date( 'F j, Y', date ) }
						</span>
					) : (
						<RichText
							allowedFormats={ [ 'core/bold', 'core/italic' ] }
							tagName="span"
							className="value"
							placeholder={ __( 'Short & sweet in 20 characters.', 'leco-cp' ) }
							value={ value }
							onChange={ ( newValue ) => setAttributes( { value: newValue } ) }
						/>
					)
				}
				<RichText
					allowedFormats={ [ 'core/bold', 'core/italic' ] }
					tagName="span"
					className="label"
					value={ label }
					onChange={ ( newLabel ) => setAttributes( { label: newLabel } ) }
				/>

			</div>
		</>
	);
}
