const { __ } = wp.i18n;
const { useBlockProps, InspectorControls } = wp.blockEditor;
const { serverSideRender: ServerSideRender } = wp;
const { PanelBody, TextControl, Tip, ToggleControl } = wp.components;

import PostsDropdownControl from './posts-dropdown-control';

export default function Edit( props ) {
	const { isSelected, setAttributes } = props;
	const {
		template,
		project,
		projectTitle,
		showOrganization,
		privacyConsentLabel,
	} = props.attributes;
	const blockProps = useBlockProps();
	const controls = [
		isSelected && (
			<InspectorControls key="inspector">
				<PanelBody
					title={ __( 'Registration Options', 'leco-cp' ) }
					initialOpen={ true }
				>
					<Tip>
						{ __(
							'When no template and portal selected, the default values from Client Portal Settings will be loaded.',
							'leco-cp'
						) }{ ' ' }
						<br />
						<br />
					</Tip>
					<PostsDropdownControl
						label={ __( 'Create New Portal', 'leco-cp' ) }
						postType="leco_template"
						value={ template }
						onChange={ ( template ) =>
							setAttributes( { template } )
						}
						isHidden={ project }
						defaultOption={ __(
							"Don't create new portal",
							'leco-cp'
						) }
						help={ __(
							"Select a portal template and we will create a new portal with the client. If you don't select one, no new portal will be created.",
							'leco-cp'
						) }
					/>
					<PostsDropdownControl
						label={ __( 'Attach a Portal', 'leco-cp' ) }
						postType="leco_client"
						value={ project }
						onChange={ ( project ) =>
							setAttributes( { project } )
						}
						isHidden={ template }
						defaultOption={ __(
							"Don't attach any portal",
							'leco-cp'
						) }
						help={ __(
							'You can attach a portal to the client.',
							'leco-cp'
						) }
					/>
					{ template ? (
						<TextControl
							label={ __( 'New Portal Title', 'leco-cp' ) }
							value={ projectTitle }
							help={ __(
								'The title of your new portal.',
								'leco-cp'
							) }
							onChange={ ( projectTitle ) =>
								setAttributes( { projectTitle } )
							}
						/>
					) : (
						''
					) }
					<ToggleControl
						label={ __(
							'Display Organization Field',
							'leco-cp'
						) }
						checked={ showOrganization }
						onChange={ () => {
							setAttributes( {
								showOrganization: ! showOrganization,
							} );
						} }
					/>
					<TextControl
						label={ __(
							'Privacy Consent Label Text',
							'leco-cp'
						) }
						value={ privacyConsentLabel }
						help={ __(
							'The label text of the Privacy consent checkbox. If left empty, the default text will be used.',
							'leco-cp'
						) }
						onChange={ ( privacyConsentLabel ) =>
							setAttributes( { privacyConsentLabel } )
						}
					/>
				</PanelBody>
			</InspectorControls>
		),
	];

	return (
		<>
			{ controls }
			<div { ...blockProps }>
				<div className="leco-cp-disable-editing">
					<ServerSideRender
						block="leco-cp/register"
						attributes={ props.attributes }
					/>
				</div>
			</div>
		</>
	);
}
