let searchBox;
let lecoSearchTimer;

const searchResults = ( event ) => {
	const keyword = event.currentTarget.value.toLowerCase();
	const container = document.querySelectorAll( '.wp-block-leco-cp-phases' );
	const modules = document.querySelectorAll( '.module-wrap' );
	const modulesWrap = document.querySelectorAll(
		'.leco-cp-phases-container'
	);
	const searchFeedback = document.querySelector( '.search-feedback' );
	const noResult = document.querySelector( '.no-result' );
	const resultsDefault = document.querySelector( '.results-default' );
	const hasResults = document.querySelector( '.has-results' );

	clearTimeout( lecoSearchTimer );

	if ( keyword.length > 2 ) {
		lecoSearchTimer = setTimeout( function () {
			const res = new Set();

			// Check search term in title and description & add items without term to new set
			[ ...modules ].forEach( ( item ) => {
				const title = item
					.getElementsByClassName( 'title' )[ 0 ]
					.innerText.toLowerCase();

				const description = item
					.getElementsByClassName( 'description' )[ 0 ]
					.innerText.toLowerCase();

				if (
					! title.includes( keyword ) &&
					! description.includes( keyword )
				) {
					res.add( item );
				}
			} );

			// Hide items without search term
			if ( res.size > 0 ) {
				// hide modules without search term
				res.forEach( ( item ) => {
					item.classList.add( 'hidden' );
				} );

				// hide containers without visible modules
				[ ...modulesWrap ].forEach( ( item ) => {
					if (
						item.querySelectorAll( '.module-wrap' ).length ===
						item.querySelectorAll( '.hidden' ).length
					) {
						item.closest(
							'.wp-block-leco-cp-phases'
						).classList.add( 'hidden' );
					}
				} );
			}

			// If all modules are hidden, show no results message
			if ( modules.length === res.size ) {
				[ ...modules ].forEach( ( item ) => {
					item.classList.remove( 'hidden' );
				} );

				[ ...container ].forEach( ( item ) => {
					item.classList.remove( 'hidden' );
				} );

				searchFeedback.classList.remove( 'hidden' );
				noResult.classList.remove( 'hidden' );

				resultsDefault.classList.add( 'hidden' );
				hasResults.classList.add( 'hidden' );
			} else {
				// If not all modules are hidden, show results message
				searchFeedback.classList.remove( 'hidden' );
				hasResults.classList.remove( 'hidden' );

				resultsDefault.classList.add( 'hidden' );
				noResult.classList.add( 'hidden' );
			}
		}, 500 );
	} else if ( keyword === '' ) {
		// reset search results
		[ ...modules ].forEach( ( item ) => {
			item.classList.remove( 'hidden' );
		} );

		[ ...container ].forEach( ( item ) => {
			item.classList.remove( 'hidden' );
		} );

		searchFeedback.classList.remove( 'hidden' );
		resultsDefault.classList.remove( 'hidden' );

		noResult.classList.add( 'hidden' );
		hasResults.classList.add( 'hidden' );
	}
};

const removeHelperText = () => {
	const searchFeedback = document.querySelector( '.search-feedback' );

	searchFeedback.classList.add( 'hidden' );
};

const addHelperText = () => {
	if ( searchBox.value === '' ) {
		return;
	}
	const searchFeedback = document.querySelector( '.search-feedback' );

	searchFeedback.classList.remove( 'hidden' );
};

const eventListeners = () => {
	searchBox.addEventListener( 'keyup', searchResults );
	searchBox.addEventListener( 'blur', removeHelperText );
	searchBox.addEventListener( 'focus', addHelperText );
};

const init = () => {
	searchBox = document.getElementById( 'docsearch' );

	if ( ! searchBox ) {
		return;
	}

	eventListeners();
};

addEventListener( 'load', ( event ) => {
	init();
} );
