/**
 * WordPress dependencies
 */
import { InnerBlocks } from '@wordpress/block-editor';
import { useSelect } from '@wordpress/data';

/**
 * Custom hook to limit the number of inner blocks.
 *
 * @see https://ryanwelcher.com/2020/10/limiting-the-block-count-for-innerblocks/
 *
 * @since 5.0
 *
 * @param {Object} props The props.
 * @return {(function(): (*|boolean))|*} The render appender.
 */
export default function useInnerBlockCountLimit( props ) {
	const { clientId } = props;
	const innerBlockCount = useSelect(
		( select ) =>
			select( 'core/block-editor' ).getBlock( clientId ).innerBlocks
	);

	return () => {
		if ( innerBlockCount.length < 1 ) {
			return <InnerBlocks.ButtonBlockAppender />;
		}

		return false;
	};
}
