import { __ } from '@wordpress/i18n';
import { withSelect } from '@wordpress/data';
import { FormTokenField, Spinner } from '@wordpress/components';

const ClientPicker = withSelect( ( select ) => {
	const { isResolving } = select( 'core/data' );
	const query = { roles: 'leco_client' };
	return {
		users: select( 'core' ).getEntityRecords( 'root', 'user', query ),
		isRequesting: isResolving( 'core', 'getEntityRecords', [ 'root', 'user', query ] ),
	};
} )( ( props ) => {
	if ( ! props?.users || props.isRequesting ) {
		return (
			<Spinner />
		);
	}

	const { meta, setMeta } = props;

	const prefix = 'leco_cp_';

	// Backwards compatibility for 5.0-rc.1.
	if ( ! meta.hasOwnProperty( prefix ) ) {
		meta[ prefix ] = meta.leco_cp_5_client || [];
	}

	const options = props.users.map( ( user ) => {
		return user.name;
	} );

	const currentClients = () => {
		if ( meta[ `${ prefix }client` ].length === 0 ) {
			return [];
		}

		const existingClients = meta[ `${ prefix }client` ].reduce( ( result, user ) => {
			const client = props.users.find( ( u ) => u.id === user );
			if ( client?.name ) {
				result.push( client.name );
			}
			return result;
		}, [] );

		return existingClients;
	};

	const updateClient = ( value ) => {
		const updatedClients = value.reduce( ( result, user ) => {
			const client = props.users.find( ( u ) => u.name === user );
			if ( client?.id ) {
				result.push( client.id );
			}
			return result;
		}, [] );

		setMeta( {
			...meta,
			[ `${ prefix }client` ]: updatedClients,
		} );
	};

	return (
		<FormTokenField
			value={ currentClients() }
			suggestions={ options }
			onChange={ updateClient }
			label={ __( 'Select Clients:', 'leco-cp' ) }
			__experimentalShowHowTo={ false }
		/>
	);
} );

export default ClientPicker;
