<?php
/**
 * Content Page Template Markup
 *
 * @since   5.0
 *
 * @package LECO\Client_Portal\Templates\Five
 */

/**
 * Header Markup
 *
 * @since   5.0
 *
 * @package LECO\Client_Portal\Templates\Five
 * @see     https://github.com/WordPress/WordPress-Coding-Standards/issues/693
 */

use LECO\Client_Portal\Project;

require_once 'header.php';

$block_content = get_the_content();

$header_content = do_blocks(
	'<!-- wp:group -->
		<div class="wp-block-group is-root-container">
		' . leco_cp_extract_raw_cover_block( $block_content ) . '
		</div>
		<!-- /wp:group -->'
);

$classes = ! leco_cp_user_has_access() ? array( 'contacts' ) : array( 'cta-section', 'contacts' );
$footer_content = do_blocks(
	'<!-- wp:group -->
		<div class="wp-block-group is-root-container">
		' . implode( '', leco_cp_extract_group_blocks_with_class( $block_content, $classes ) ) . '
		</div>
		<!-- /wp:group -->'
);

wp_head();
?>

</head>
<body <?php body_class( 'editor-styles-wrapper' ); ?>>
<?php wp_body_open(); ?>
<?php echo $header_content; ?>
<main>
	<?php
	// If post password required and it doesn't match the cookie.
	if ( post_password_required( get_the_ID() ) ) :
		echo '<div class="content-section"><div class="leco-cp-container"><div class="password-protect">' . get_the_password_form( get_the_ID() ) . '</div></div></div>';
	else :
		if ( leco_cp_can_display_project() ) :
			$content_pages = get_posts(
				array(
					'post_type' => 'leco_content_page',
					'name'      => get_query_var( 'leco_content_page' ),
				)
			);
			?>
			<div class="main-content">
				<div class="leco-cp-container">
					<div class="leco-cp-sidebar">
						<h2 class="leco-cp-back-to-project"><a
								href="<?php echo trailingslashit( home_url( leco_cp_get_slug() . '/' . get_query_var( 'leco_client' ) ) ); ?>"
								title="<?php echo apply_filters( 'leco_cp_back_to_project_text', esc_html__( 'Back to Portal', 'leco-cp' ) ); ?>"><span
									class="iconset"><?php echo file_get_contents( LECO_CLIENT_PORTAL_DIR . 'assets/icon/caviar/chevon-left.svg' ); ?></span><?php echo apply_filters( 'leco_cp_back_to_project_text', esc_html__( 'Back to Project', 'leco-cp' ) ); ?>
							</a></h2>
						<?php
						// Get phases and modules.
						$phases = Project::get_phases( $block_content );
						$number_of_parts = count( $phases );
						$can_view = current_user_can( 'administrator' ) ? 1 : 0;

						$image_exts = array( 'jpg', 'jpeg', 'jpe', 'gif', 'png' );

						for ( $i = 0; $i < $number_of_parts; $i ++ ) {
							$number  = $i + 1;
							$modules = Project::get_modules( get_the_ID(), $phases[ $i ]['uid'] );
							if ( $modules ) {
								if ( leco_cp_modules_have_current_content_page( $modules, $content_pages[0]->ID ) ) {
									$collapse = 0;
									$can_view = 1;
								} else {
									$collapse = 1;
								}
								?>
								<h2>
									<a href="javascript:void(0)"
									   title="<?php $section = leco_cp_unescape_string( esc_attr( $phases[ $i ]['title'] ) );
									   echo $section; ?>">
										<?php echo $section; ?>
										<?php
										if ( ! $collapse ) { ?>
											<span class="iconset down"><?php echo file_get_contents( LECO_CLIENT_PORTAL_DIR . 'assets/icon/caviar/chevron-down.svg' ); ?></span>
											<span class="iconset right hidden"><?php echo file_get_contents( LECO_CLIENT_PORTAL_DIR . 'assets/icon/caviar/chevron-right.svg' ); ?></span>
										<?php } else { ?>
											<span class="iconset down hidden"><?php echo file_get_contents( LECO_CLIENT_PORTAL_DIR . 'assets/icon/caviar/chevron-down.svg' ); ?></span>
											<span class="iconset right"><?php echo file_get_contents( LECO_CLIENT_PORTAL_DIR . 'assets/icon/caviar/chevron-right.svg' ); ?></span>
										<?php }
										?>
									</a>
								</h2>
								<ul class="<?php echo ( $collapse ) ? 'collapse-menu' : ''; ?>">
									<?php
									foreach ( $modules as $key => $module ) {
										$type = ( isset( $module['type'] ) ) ? $module['type'] : 'module-links';
										$url  = get_permalink() . "#m_{$i}_{$module['uid']}";
										?>
										<li>
											<a class="<?php if ( 'content-page' === $type && $content_pages[0]->ID === $module['content_page'] ) {
												echo 'current';

												$url = 'javascript:void(0)';
											} ?>"
											   href="<?php echo $url; ?>"
											>
												<span class="iconset"><?php echo leco_cp_get_module_icon( $module['icon'], $key, $number ); ?></span>
												<?php echo $module['title']; ?>
											</a>
										</li>
										<?php
									} ?>
								</ul>
								<?php
							}
						}
						?>
					</div>
					<div class="leco-cp-content editor">
						<?php
						// checking if this content page is attached under the project, ref: https://trello.com/c/ul2doV5k.
						if ( $can_view ) {
							echo apply_filters( 'the_content', $content_pages[0]->post_content );
						} else {
							echo esc_html__( 'You don\'t have permissions to view this content.', 'leco-cp' );
						}
						?>
					</div>
				</div>
			</div>
		<?php else : ?>
			<div class="content-section">
				<div class="leco-cp-container">
					<?php
					echo leco_cp_login_form();
					?>
				</div>
			</div>
		<?php endif; ?>
	<?php endif; ?>
</main>
<?php echo $footer_content; ?>
<?php require_once 'footer.php'; ?>
