<?php

use LECO\Client_Portal\Login;

/**
 * Enqueue front end styles.
 *
 * @since 5.0
 *
 * @return void
 */
function leco_cp_enqueue_styles_fe() {

	if ( ! leco_client_portal()->is_five() ) {
		return;
	}

	// Use minified libraries if SCRIPT_DEBUG is turned off.
	$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

	wp_register_style( 'leco-cp-blocks', LECO_CLIENT_PORTAL_URL . "templates/tailwind/build/blocks{$suffix}.css", array(), LECO_CLIENT_PORTAL_VER );

	if ( Login::is_login_page() ) {
		wp_register_style( 'leco-cp-google-fonts', '//fonts.googleapis.com/css?family=Open+Sans:400,300,600,700,800&display=swap', array(), LECO_CLIENT_PORTAL_VER );
		wp_register_style( 'leco-cp-style', LECO_CLIENT_PORTAL_URL . "templates/tailwind/build/style{$suffix}.css", [ 'dashicons' ], LECO_CLIENT_PORTAL_VER );
		wp_enqueue_style( 'leco-cp-style' );
		wp_enqueue_style( 'leco-cp-blocks' );

		// Remove the global styles for FSE.
		wp_dequeue_style( 'global-styles' );
	}

	if ( ! is_singular( 'leco_client' ) && ! is_post_type_archive( 'leco_client' ) ) {
		return;
	}

    wp_enqueue_style( 'leco-cp-five-reset', LECO_CLIENT_PORTAL_URL . "templates/five/build/reset{$suffix}.css", array(), LECO_CLIENT_PORTAL_VER );
	wp_enqueue_style( 'leco-cp-five', LECO_CLIENT_PORTAL_URL . "templates/five/build/styles{$suffix}.css", array('leco-cp-five-reset'), LECO_CLIENT_PORTAL_VER );
	wp_enqueue_style( 'leco-cp-blocks' );

	wp_enqueue_script( 'leco-cp-five-content-page', LECO_CLIENT_PORTAL_URL . 'build/content-page.js', array( 'jquery' ), LECO_CLIENT_PORTAL_VER, true );

}

add_action( 'wp_enqueue_scripts', 'leco_cp_enqueue_styles_fe' );

function leco_cp_register_scripts() {
	if ( ! is_singular( 'leco_client' ) && ! is_post_type_archive( 'leco_client' ) ) {
		return;
	}

	wp_enqueue_script( 'leco-cp-lity', LECO_CLIENT_PORTAL_URL . 'templates/tailwind/assets/js/lity.min.js', array( 'jquery' ), LECO_CLIENT_PORTAL_VER );
	wp_enqueue_style( 'leco-cp-lity', LECO_CLIENT_PORTAL_URL . 'templates/tailwind/assets/css/lity.min.css', array(), LECO_CLIENT_PORTAL_VER );
	wp_enqueue_style( 'leco-cp-lity-mods', LECO_CLIENT_PORTAL_URL . 'templates/five/src/lity.css', array(), LECO_CLIENT_PORTAL_VER );

	$vars = array(
		'_wpnonce'             => wp_create_nonce( 'leco_cp_ajax_nonce' ),
		'post_id'              => get_the_ID(),
		'ajaxurl'              => admin_url( 'admin-ajax.php', 'relative' ),
		'delete_client_upload' => wp_strip_all_tags( __( 'Are you sure to delete this file?', 'leco-cp' ) ),
		'flash_swf_url'        => includes_url( 'js/plupload/plupload.flash.swf' ),
		'silverlight_xap_url'  => includes_url( 'js/plupload/plupload.silverlight.xap' ),
		'filters'              => array(
			'mime_types'    => array(
				array(
					'title'      => wp_strip_all_tags( __( 'Allowed Files', 'leco-cp' ) ),
					'extensions' => LECO_CP_Client_Upload::get_allowed_extension(),
				),
			),
			'max_file_size' => wp_max_upload_size() . 'b',
		),
		'failed_to_upload'     => wp_strip_all_tags( __( 'Failed to upload file: ', 'leco-cp' ) ),
		'error'                => wp_strip_all_tags( __( 'Error: ', 'leco-cp' ) ),
		'download'             => wp_strip_all_tags( __( 'Download', 'leco-cp' ) ),
		'close'                => wp_strip_all_tags( __( 'Close', 'leco-cp' ) ),
		'close_a11y'           => wp_strip_all_tags( __( 'Close (Press escape to close)', 'leco-cp' ) ),
	);
	wp_localize_script( 'leco-cp-scripts', 'lecoCPVars', $vars );
}

add_action( 'wp_enqueue_scripts', 'leco_cp_register_scripts' );

/**
 * Add body classes.
 *
 * @since 5.0
 *
 * @param array $classes Classes.
 *
 * @return array
 */
function leco_cp_five_body_class( $classes ) {
	if ( get_query_var( 'leco_content_page' ) ) {
		$classes[] = 'leco-content-page';
	}

	return $classes;
}
add_filter( 'body_class', 'leco_cp_five_body_class' );

/**
 * Extract the raw cover block from the post content.
 *
 * @since 5.0
 *
 * @param string $post_content The post content.
 *
 * @return string
 */
function leco_cp_extract_raw_cover_block( $post_content ) {
	// Pattern to match the wp:cover block, including its start and end tags
	// and capturing everything in between.
	$pattern = '/(<!-- wp:cover.*?-->)(.*?)(<!-- \/wp:cover -->)/s';

	// Attempt to find a match using the pattern
	if ( preg_match( $pattern, $post_content, $matches ) ) {
		// If a match is found, return the full match (including the start and end tags)
		return $matches[0];
	}

	// Return an empty string if no cover block is found
	return '';
}

/**
 * Extracts the last two 'wp:group' blocks with specific class names from the post content.
 *
 * @sicne 5.0
 *
 * @param string $content         The raw post content.
 * @param array  $allowed_classes An array of class names to check for in the 'className' attribute.
 *
 * @return array Matches of the last two 'wp:group' blocks with specified class names.
 */
function leco_cp_extract_group_blocks_with_class( $content, $allowed_classes ) {
	// Adjusted pattern to try and more accurately capture up to the closing tag of 'wp:group'.
	$pattern = "/<!-- wp:group (.*?) -->(.*?)<!-- \/wp:group -->/s";

	preg_match_all( $pattern, $content, $matches, PREG_SET_ORDER );

	$filtered_blocks = array_filter( $matches, function ( $match ) use (
		$allowed_classes
	) {
		if ( strpos( $match[1], '"className":"' ) !== false ) {
			preg_match( '/"className":"([^"]*?)"/', $match[1], $classMatches );
			if ( ! empty( $classMatches[1] ) ) {
				$classNames = explode( " ", $classMatches[1] );
				foreach ( $allowed_classes as $allowed_class ) {
					if ( in_array( $allowed_class, $classNames ) ) {
						return true;
					}
				}
			}
		}

		return false;
	} );

	return array_map( function ( $match ) {
		return $match[0];
	}, $filtered_blocks );
}

/**
 * If one of the modules has the current content page.
 *
 * @since 5.0
 *
 * @param array $modules The modules to search.
 * @param int   $post_id The post ID to search for.
 *
 * @return bool
 */
function leco_cp_modules_have_current_content_page( $modules, $post_id ) {
	foreach( $modules as $module ) {
		if ( isset( $module['content_page'] ) && $module['content_page'] === $post_id ) {
			return true;
		}
	}

	return false;
}

/**
 * Somehow Phase title is escaped twice, this function will unescape it.
 *
 * @since 5.0.0
 *
 * @param string $string The string to unescape.
 *
 * @return string
 */
function leco_cp_unescape_string( $string ) {
	// Decode Unicode escape sequences.
	$decodedString = json_decode( '"' . $string . '"' );

	// Convert HTML entities to characters.
	return html_entity_decode( $decodedString, ENT_QUOTES | ENT_HTML5, 'UTF-8' );
}
